<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage EduMag Pro
 * @since EduMag Pro 1.0
 */

if ( ! function_exists( 'edumag_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'edumag_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'edumag_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'edumag_pro_theme_options[pagination_enable]' )->value();
	}
endif;

if ( ! function_exists( 'edumag_pro_is_top_header_active' ) ) :
	/**
	 * Check if top header is enabled.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_is_top_header_active( $control ) {
		return $control->manager->get_setting( 'edumag_pro_theme_options[enable_top_header]' )->value();
	}
endif;

if ( ! function_exists( 'edumag_pro_is_address_block_active' ) ) :
	/**
	 * Check if address block is enabled.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_is_address_block_active( $control ) {
		if ( edumag_pro_is_top_header_active( $control ) && $control->manager->get_setting( 'edumag_pro_theme_options[enable_address_block]' )->value() ){
			return true;
		} else{
			return false;
		}
	}
endif;

if ( ! function_exists( 'edumag_pro_is_social_link_block_active' ) ) :
	/**
	 * Check if social link block is enabled.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_is_social_link_block_active( $control ) {
		if ( edumag_pro_is_top_header_active( $control ) && $control->manager->get_setting( 'edumag_pro_theme_options[enable_social_link_block]' )->value() ){
			return true;
		} else{
			return false;
		}
	}
endif;

if ( ! function_exists( 'edumag_pro_is_custom_link_block_active' ) ) :
	/**
	 * Check if custom link block is enabled.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_is_custom_link_block_active( $control ) {
		if ( edumag_pro_is_top_header_active( $control ) && $control->manager->get_setting( 'edumag_pro_theme_options[enable_custom_link_block]' )->value() ){
			return true;
		} else{
			return false;
		}
	}
endif;

// Active callback for featured category section

if ( ! function_exists( 'edumag_pro_is_featured_category_section_active' ) ) :
	/**
	 * Check if featured category section is active.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_is_featured_category_section_active( $control ) {
		
			return ( 'static-frontpage' == $control->manager->get_setting( 'edumag_pro_theme_options[featured_category_enable]' )->value() );
	}
endif;

if ( ! function_exists( 'edumag_pro_featured_category_content_category_active' ) ) :
	/**
	 * Check if content category is active.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_featured_category_content_category_active( $control ) {
		
			return ( edumag_pro_is_featured_category_section_active( $control ) && ( 'category' == $control->manager->get_setting( 'edumag_pro_theme_options[featured_category_content_type]' )->value() ) );
	}
endif;

if ( ! function_exists( 'edumag_pro_featured_category_content_post_active' ) ) :
	/**
	 * Check if content posts is active.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_featured_category_content_post_active( $control ) {
		
			return ( edumag_pro_is_featured_category_section_active( $control ) && ( 'posts' == $control->manager->get_setting( 'edumag_pro_theme_options[featured_category_content_type]' )->value() ) );
	}
endif;

// Active callback for popular articles

if ( ! function_exists( 'edumag_pro_is_popular_articles_section_active' ) ) :
	/**
	 * Check if popular articles section is active.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_is_popular_articles_section_active( $control ) {
		
			return ( 'static-frontpage' == $control->manager->get_setting( 'edumag_pro_theme_options[popular_articles_enable]' )->value() );
	}
endif;

if ( ! function_exists( 'edumag_pro_is_demo_content_inactive' ) ) :
	/**
	 * Check if demo content is inactive.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_is_demo_content_inactive( $control ) {
		
			return ( edumag_pro_is_featured_category_section_active( $control ) && ( 'demo' != $control->manager->get_setting( 'edumag_pro_theme_options[popular_articles_content_type]' )->value() ) );
	}
endif;

if ( ! function_exists( 'edumag_pro_is_popular_article_ad_image_active' ) ) :
	/**
	 * Check if ad image is active.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_is_popular_article_ad_image_active( $control ) {
		
			return ( edumag_pro_is_featured_category_section_active( $control ) && ( 'ad_image' == $control->manager->get_setting( 'edumag_pro_theme_options[popular_articles_ad_type]' )->value() ) );
	}
endif;

if ( ! function_exists( 'edumag_pro_is_popular_article_ad_code_active' ) ) :
	/**
	 * Check if ad code is active.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_is_popular_article_ad_code_active( $control ) {
		
			return ( edumag_pro_is_featured_category_section_active( $control ) && ( 'ad_code' == $control->manager->get_setting( 'edumag_pro_theme_options[popular_articles_ad_type]' )->value() ) );
	}
endif;

/*
 *
 * Active callback for search section
 *
 */

if ( ! function_exists( 'edumag_pro_is_search_section_active' ) ) :
	/**
	 * Check if search section is active.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_is_search_section_active( $control ) {
		
			return ( 'static-frontpage' == $control->manager->get_setting( 'edumag_pro_theme_options[search_section_enable]' )->value() );
	}
endif;

if ( ! function_exists( 'edumag_pro_is_search_section_custom_post_active' ) ) :
	/**
	 * Check if search section custom post is active.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_is_search_section_custom_post_active( $control ) {
		
			return ( edumag_pro_is_search_section_active( $control ) && 'custom-posts' == $control->manager->get_setting( 'edumag_pro_theme_options[search_section_search_in]' )->value() );
	}
endif;

/*
 *
 * Active callback for trending section
 *
 */

if ( ! function_exists( 'edumag_pro_is_trending_section_active' ) ) :
	/**
	 * Check if trending section is active.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_is_trending_section_active( $control ) {
		
			return ( 'static-frontpage' == $control->manager->get_setting( 'edumag_pro_theme_options[trending_section_enable]' )->value() );
	}
endif;

/*
 *
 * Active callback for trending section cotent type category
 *
 */

if ( ! function_exists( 'edumag_pro_is_trending_section_category_active' ) ) :
	/**
	 * Check if trending section is category active.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_is_trending_section_category_active( $control ) {
		
			return ( edumag_pro_is_trending_section_active( $control ) && ( 'category' == $control->manager->get_setting( 'edumag_pro_theme_options[trending_section_content_type]' )->value() ) );
	}
endif;

if ( ! function_exists( 'edumag_pro_is_trending_section_taxonomy_active' ) ) :
	/**
	 * Check if trending section taxonomy is active.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_is_trending_section_taxonomy_active( $control ) {
		if ( edumag_pro_is_trending_section_active( $control ) && 'category' != $control->manager->get_setting( 'edumag_pro_theme_options[trending_section_content_type]' )->value() && 'demo' != $control->manager->get_setting( 'edumag_pro_theme_options[trending_section_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'edumag_pro_is_trending_section_not_demo' ) ) :
	/**
	 * Check if trending section content is not demo.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function edumag_pro_is_trending_section_not_demo( $control ) {
		if ( edumag_pro_is_trending_section_active( $control ) && 'demo' != $control->manager->get_setting( 'edumag_pro_theme_options[trending_section_content_type]' )->value() )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'edumag_pro_is_trending_section_subscription_active' ) ) :
	/**
	 * Check if trending section subscription is active.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */

	function edumag_pro_is_trending_section_subscription_active( $control ) {
		if ( edumag_pro_is_trending_section_not_demo( $control ) && $control->manager->get_setting( 'edumag_pro_theme_options[trending_section_enable_subscription]' )->value() )
			return true;

		return false;
	}
endif;
/*
 *
 * Active callback for advertisement section
 *
 */

if ( ! function_exists( 'edumag_pro_is_advertisement_section_active' ) ) :
	/**
	 * Check if advertisement section is active.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_is_advertisement_section_active( $control ) {
		
			return ( 'static-frontpage' == $control->manager->get_setting( 'edumag_pro_theme_options[advertisement_section_enable]' )->value() );
	}
endif;

if ( ! function_exists( 'edumag_pro_is_advertisement_section_ad_image_active' ) ) :
	/**
	 * Check if ad image is active.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_is_advertisement_section_ad_image_active( $control ) {
		
			return ( edumag_pro_is_advertisement_section_active( $control ) && ( 'ad_image' == $control->manager->get_setting( 'edumag_pro_theme_options[advertisement_section_ad_type]' )->value() ) );
	}
endif;

if ( ! function_exists( 'edumag_pro_is_advertisement_section_ad_code_active' ) ) :
	/**
	 * Check if ad code is active.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_is_advertisement_section_ad_code_active( $control ) {		
		return ( edumag_pro_is_advertisement_section_active( $control ) && ( 'ad_code' == $control->manager->get_setting( 'edumag_pro_theme_options[advertisement_section_ad_type]' )->value() ) );
	}
endif;

/*
 *
 * Active callback for latest news section
 *
 */

if ( ! function_exists( 'edumag_pro_is_latest_news_section_active' ) ) :
	/**
	 * Check if latest news section is active.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_is_latest_news_section_active( $control ) {		
		return ( 'static-frontpage' == $control->manager->get_setting( 'edumag_pro_theme_options[latest_news_enable]' )->value() );
	}
endif;

if ( ! function_exists( 'edumag_pro_is_latest_news_category_active' ) ) :
	/**
	 * Check if category content of latest news section is active.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_is_latest_news_category_active( $control ) {
		
			return ( edumag_pro_is_latest_news_section_active( $control ) && ( 'category' == $control->manager->get_setting( 'edumag_pro_theme_options[latest_news_content_type]' )->value() ) );
	}
endif;

if ( ! function_exists( 'edumag_pro_is_latest_news_custom_taxonomy_active' ) ) :
	/**
	 * Check if custom taxonomy of latest news section is active.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_is_latest_news_custom_taxonomy_active( $control ) {
		if ( edumag_pro_is_latest_news_section_active( $control ) && 'category' != $control->manager->get_setting( 'edumag_pro_theme_options[latest_news_content_type]' )->value() && 'demo' != $control->manager->get_setting( 'edumag_pro_theme_options[latest_news_content_type]' )->value() )
			return true;

		return false;
	}
endif;


/*
 *
 * Active callback for blogs section
 *
 */

if ( ! function_exists( 'edumag_pro_is_blogs_section_active' ) ) :
	/**
	 * Check if blogs section is active.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_is_blogs_section_active( $control ) {		
		return ( 'static-frontpage' == $control->manager->get_setting( 'edumag_pro_theme_options[blogs_section_enable]' )->value() );
	}
endif;

if ( ! function_exists( 'edumag_pro_blogs_content_post_active' ) ) :
	/**
	 * Check if post content of blogs section is active.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_blogs_content_post_active( $control ) {
		
			return ( edumag_pro_is_blogs_section_active( $control ) && ( 'posts' == $control->manager->get_setting( 'edumag_pro_theme_options[blogs_section_content_type]' )->value() ) );
	}
endif;

if ( ! function_exists( 'edumag_pro_blogs_content_category_active' ) ) :
	/**
	 * Check if category content of blogs section is active.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_blogs_content_category_active( $control ) {
		
			return ( edumag_pro_is_blogs_section_active( $control ) && ( 'category' == $control->manager->get_setting( 'edumag_pro_theme_options[blogs_section_content_type]' )->value() ) );
	}
endif;


/*
 *
 * Active callback for contact us page template
 *
 */
if ( ! function_exists( 'edumag_pro_is_contact_map_active' ) ) :
	/**
	 * Check if map section is active in contact us page template.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_is_contact_map_active( $control ) {		
		return ( $control->manager->get_setting( 'edumag_pro_theme_options[enable_map_section]' )->value() );
	}
endif;

if ( ! function_exists( 'edumag_pro_contact_map_embed_active' ) ) :
	/**
	 * Check if map section is embed code option active.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_contact_map_embed_active( $control ) {		
		return ( edumag_pro_is_contact_map_active( $control ) && ( 'embed' == $control->manager->get_setting( 'edumag_pro_theme_options[map_type_option]' )->value() ) );
	}
endif;

if ( ! function_exists( 'edumag_pro_contact_map_shortcode_active' ) ) :
	/**
	 * Check if contact map option active.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_contact_map_shortcode_active( $control ) {		
		return ( edumag_pro_is_contact_map_active( $control ) && ( 'shortcode' == $control->manager->get_setting( 'edumag_pro_theme_options[map_type_option]' )->value() ) );
	}
endif;

if ( ! function_exists( 'edumag_pro_is_contact_form_active' ) ) :
	/**
	 * Check if map section is contact form active.
	 *
	 * @since EduMag Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function edumag_pro_is_contact_form_active( $control ) {		
		return ( $control->manager->get_setting( 'edumag_pro_theme_options[enable_contact_form]' )->value() );
	}
endif;