<?php
/**
 * EduMag Pro Latest News Customizer options
 *
 * @package Theme Palace
 * @subpackage EduMag Pro
 * @since EduMag Pro 1.0
 */

// Add latest news enable section
$wp_customize->add_section( 'edumag_pro_latest_news_section', array(
	'title'             => esc_html__( 'Latest News','edumag-pro'),
	'description'       => esc_html__( 'Latest news section options.', 'edumag-pro' ),
	'panel'             => 'edumag_pro_sections_panel'
) );

// Add latest news enable setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[latest_news_enable]', array(
	'default'           => $options['latest_news_enable'],
	'sanitize_callback' => 'edumag_pro_sanitize_select'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[latest_news_enable]', array(
	'label'             => esc_html__( 'Enable on', 'edumag-pro' ),
	'section'           => 'edumag_pro_latest_news_section',
	'type'              => 'select',
	'choices'           => edumag_pro_enable_disable_options()
) );

// Add latest news title setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[latest_news_title]', array(
	'default'           => $options['latest_news_title'],
	'transport'			=> 'postMessage',
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[latest_news_title]', array(
	'label'           	=> esc_html__( 'Title', 'edumag-pro' ),
	'section'         	=> 'edumag_pro_latest_news_section',
	'active_callback' 	=> 'edumag_pro_is_latest_news_section_active',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'edumag_pro_theme_options[latest_news_title]', array(
		'selector'            => '#latest-news h2.entry-title',
		'render_callback'     => 'edumag_pro_customize_partial_latest_news_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Add latest news sub title setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[latest_news_subtitle]', array(
	'default'           => $options['latest_news_subtitle'],
	'transport'			=> 'postMessage',
	'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[latest_news_subtitle]', array(
	'label'           	=> esc_html__( 'Description', 'edumag-pro' ),
	'section'         	=> 'edumag_pro_latest_news_section',
	'type'				=> 'textarea',
	'active_callback' 	=> 'edumag_pro_is_latest_news_section_active',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'edumag_pro_theme_options[latest_news_subtitle]', array(
		'selector'            => '#latest-news p.sub-title',
		'render_callback'     => 'edumag_pro_customize_partial_latest_news_subtitle',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}


// Add trending section content type setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[latest_news_content_type]', array(
  'default'           => $options['latest_news_content_type'],
  'sanitize_callback' => 'edumag_pro_sanitize_select'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[latest_news_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'edumag-pro' ),
    'description'		=> sprintf( '%s<b> %s </b> %s <b> %s </b>', esc_html__( 'Save and then refresh page after changing', 'edumag-pro' ), esc_html__( 'Content Type', 'edumag-pro' ), esc_html__( 'to', 'edumag-pro' ), esc_html__( 'select Terms', 'edumag-pro' ) ),
    'section'           => 'edumag_pro_latest_news_section',
    'active_callback'   => 'edumag_pro_is_latest_news_section_active',
    'type'              => 'select',
    'choices'           =>  edumag_pro_information_taxonomy_content_type(),
    'active_callback'	=> 'edumag_pro_is_latest_news_section_active'
) );

// Category Content Type
$wp_customize->add_setting(  'edumag_pro_theme_options[latest_news_content_category]', array(
  'sanitize_callback' => 'edumag_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Edumag_Pro_Multi_Select_Category_Control ( $wp_customize,'edumag_pro_theme_options[latest_news_content_category]', array(
  'label'             => esc_html__( 'Select Category', 'edumag-pro' ),
  'section'           => 'edumag_pro_latest_news_section',
  'type'              => 'dropdown-category',
  'active_callback'   => 'edumag_pro_is_latest_news_category_active'
) ) );

// Taxonomy Content Type
$wp_customize->add_setting(  'edumag_pro_theme_options[latest_news_'. $options['latest_news_content_type'] .']', array(
  	'sanitize_callback' => 'edumag_pro_sanitize_multi_select_taxonomies_control',
) ) ;

$wp_customize->add_control( new Edumag_Pro_Multi_Select_Taxonomies_Control ( $wp_customize,'edumag_pro_theme_options[latest_news_'. $options['latest_news_content_type'] .']', array(
  'label'             => esc_html__( 'Select Terms', 'edumag-pro' ),
  'section'           => 'edumag_pro_latest_news_section',
  'taxonomy'          => $options['latest_news_content_type'],
  'type'              => 'dropdown-taxonomies',
  'active_callback' => 'edumag_pro_is_latest_news_custom_taxonomy_active'
) ) );
