<?php
/**
 * Top header options
 *
 * @package Theme Palace
 * @subpackage EduMag Pro
 * @since EduMag Pro 1.0
 */

/**
* Top header section
*/
// Add top header enable section
$wp_customize->add_section( 'edumag_pro_top_header_section', array(
	'title'             => esc_html__( 'Top Header', 'edumag-pro' ),
	'description'       => esc_html__( 'Let you modify top header address and social icons', 'edumag-pro' ),
	'panel'             => 'edumag_pro_sections_panel',
) );

// Add top header enable setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[enable_top_header]', array(
	'default'           => $options['enable_top_header'],
	'sanitize_callback' => 'edumag_pro_sanitize_checkbox',
) );

$wp_customize->add_control( 'edumag_pro_theme_options[enable_top_header]', array(
	'label'             => esc_html__( 'Enable top Header', 'edumag-pro' ),
	'section'           => 'edumag_pro_top_header_section',
	'type'              => 'checkbox',
) );

// Add title for address block
$wp_customize->add_setting( 'edumag_pro_theme_options[left_part_address_block]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$description = esc_html__( 'Example fa-refresh see more at', 'edumag-pro' ) . sprintf( '<a target="_blank" href="' . esc_url( 'http://fontawesome.io/icons/' ) . '"> %s </a>', esc_html__( 'Font awesome', 'edumag-pro' ) );

$wp_customize->add_control( new Edumag_Pro_Note_Control( $wp_customize, 'edumag_pro_theme_options[left_part_address_block]', array(
	'label'           	=> esc_html__( 'Address Block', 'edumag-pro' ),
	'description'		=> $description,
	'section'         	=> 'edumag_pro_top_header_section',
	'type'            	=> 'description',
	'active_callback' 	=> 'edumag_pro_is_top_header_active',
) ) );

// Add contact enable setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[enable_address_block]', array(
	'default'           => $options['enable_address_block'],
	'sanitize_callback' => 'edumag_pro_sanitize_checkbox',
) );

$wp_customize->add_control( 'edumag_pro_theme_options[enable_address_block]', array(
	'label'             => esc_html__( 'Enable Address Block', 'edumag-pro' ),
	'section'           => 'edumag_pro_top_header_section',
	'type'              => 'checkbox',
	'active_callback' 	=> 'edumag_pro_is_top_header_active',

) );


// Add contact phone icon setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[contact_phone_icon]', array(
	'default'           => $options['contact_phone_icon'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[contact_phone_icon]', array(
	'active_callback' 	=> 'edumag_pro_is_address_block_active',
	'label'             => esc_html__( 'Phone Icon', 'edumag-pro' ),
	'section'           => 'edumag_pro_top_header_section',
	'input_attrs'		=> array( 'placeholder' => esc_attr( esc_html__( 'fa-phone', 'edumag-pro' ) ),

) ) );

// Add contact phone number setting and control
$wp_customize->add_setting( 'edumag_pro_theme_options[contact_phone_number]', array(
	'default'			=> $options['contact_phone_number'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'edumag_pro_theme_options[contact_phone_number]', array(
	'label'           	=> esc_html__( 'Phone Number', 'edumag-pro' ),
	'description'		=> esc_html__( 'Enter phone number', 'edumag-pro' ),
	'section'         	=> 'edumag_pro_top_header_section',
	'active_callback' 	=> 'edumag_pro_is_address_block_active',
	'type'				=> 'text'
) );

// Add contact fax icon setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[contact_email_icon]', array(
	'default'           => $options['contact_email_icon'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[contact_email_icon]', array(
	'active_callback' 	=> 'edumag_pro_is_address_block_active',
	'label'             => esc_html__( 'Email Icon', 'edumag-pro' ),
	'section'           => 'edumag_pro_top_header_section',
	'input_attrs'		=> array( 'placeholder' => esc_attr( esc_html__( 'fa-envelope', 'edumag-pro' ) ),

) ) );

// Add Email setting and control
$wp_customize->add_setting( 'edumag_pro_theme_options[contact_email]', array(
	'default'			=> $options['contact_email'],
	'sanitize_callback' => 'sanitize_email',
) );

$wp_customize->add_control( 'edumag_pro_theme_options[contact_email]', array(
	'label'           	=> esc_html__( 'Contact Email', 'edumag-pro' ),
	'description'		=> esc_html__( 'Enter email', 'edumag-pro' ),
	'section'         	=> 'edumag_pro_top_header_section',
	'active_callback' 	=> 'edumag_pro_is_address_block_active',
	'type'				=> 'email'
) );

// Add contact fax icon setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[skype_icon]', array(
	'default'           => $options['skype_icon'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[skype_icon]', array(
	'label'             => esc_html__( 'Skype Icon', 'edumag-pro' ),
	'section'           => 'edumag_pro_top_header_section',
	'input_attrs'		=> array( 'placeholder' => esc_attr__( 'fa-skype', 'edumag-pro' ) ),
	'active_callback' 	=> 'edumag_pro_is_address_block_active',

) );

$wp_customize->add_setting( 'edumag_pro_theme_options[skype_link]', array(
	'default'			=> $options['skype_link'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'edumag_pro_theme_options[skype_link]', array(
	'label'             =>  esc_html__( 'Skype Link', 'edumag-pro' ),
	'section'           => 'edumag_pro_top_header_section',
	'type'              => 'text',
	'active_callback' 	=> 'edumag_pro_is_address_block_active',
) );

// Add title for social links block
$wp_customize->add_setting( 'edumag_pro_theme_options[right_part_social_block]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( new Edumag_Pro_Note_Control( $wp_customize, 'edumag_pro_theme_options[right_part_social_block]', array(
	'label'           	=> esc_html__( 'Social links Block', 'edumag-pro' ),
	'section'         	=> 'edumag_pro_top_header_section',
	'type'            	=> 'description',
	'active_callback' 	=> 'edumag_pro_is_top_header_active',
) ) );

// Add  enable social links block setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[enable_social_link_block]', array(
	'default'           => $options['enable_social_link_block'],
	'sanitize_callback' => 'edumag_pro_sanitize_checkbox',
) );

$wp_customize->add_control( 'edumag_pro_theme_options[enable_social_link_block]', array(
	'label'             => esc_html__( 'Enable Social Links Block', 'edumag-pro' ),
	'section'           => 'edumag_pro_top_header_section',
	'type'              => 'checkbox',
	'active_callback' 	=> 'edumag_pro_is_top_header_active',

) );

// Add no of social link setting and control
$wp_customize->add_setting( 'edumag_pro_theme_options[no_of_social_link]', array(
	'default'			=> $options['no_of_social_link'],
	'sanitize_callback' => 'edumag_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'edumag_pro_theme_options[no_of_social_link]', array(
	'label'           	=> esc_html__( 'Number of Social Links', 'edumag-pro' ),
	'description'		=> esc_html__( 'Enter number of social links. Save and then refresh page to view changes. Min 2 and Max 5', 'edumag-pro' ),
	'section'         	=> 'edumag_pro_top_header_section',
	'active_callback' 	=> 'edumag_pro_is_social_link_block_active',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'			=> 2,
		'max'			=> 5,
		'step'			=> 1
	)
) );

$no_of_social_link =  edumag_pro_get_theme_options()['no_of_social_link']; // get no of social link

for( $i=1; $i<= $no_of_social_link; $i++ ){
	// Add  enable social links block setting and control.
	$wp_customize->add_setting( 'edumag_pro_theme_options[social_link_'. $i .']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'edumag_pro_theme_options[social_link_'. $i .']', array(
		'label'             => sprintf( esc_html__( 'Social Link #%s', 'edumag-pro' ), $i ),
		'section'           => 'edumag_pro_top_header_section',
		'type'              => 'url',
		'active_callback' 	=> 'edumag_pro_is_social_link_block_active',

	) );
}

// Add title for custom links block
$wp_customize->add_setting( 'edumag_pro_theme_options[custom_links_block]', array(
	'sanitize_callback'	=> 'esc_html',
) );

$wp_customize->add_control( new Edumag_Pro_Note_Control( $wp_customize, 'edumag_pro_theme_options[custom_links_block]', array(
	'label'           	=> esc_html__( 'Custom links Block', 'edumag-pro' ),
	'description'		=> esc_html__( 'Section to add custom links like sign up, sign in or external links', 'edumag-pro' ),
	'section'         	=> 'edumag_pro_top_header_section',
	'type'            	=> 'description',
	'active_callback' 	=> 'edumag_pro_is_top_header_active',
) ) );

// Add enable custom links block setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[enable_custom_link_block]', array(
	'default'           => $options['enable_custom_link_block'],
	'sanitize_callback' => 'edumag_pro_sanitize_checkbox',
) );

$wp_customize->add_control( 'edumag_pro_theme_options[enable_custom_link_block]', array(
	'label'             => esc_html__( 'Enable Custom Links Block', 'edumag-pro' ),
	'section'           => 'edumag_pro_top_header_section',
	'type'              => 'checkbox',
	'active_callback' 	=> 'edumag_pro_is_top_header_active',

) );

// Add no of custom link setting and control
$wp_customize->add_setting( 'edumag_pro_theme_options[no_of_custom_link]', array(
	'default'			=> $options['no_of_custom_link'],
	'sanitize_callback' => 'edumag_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'edumag_pro_theme_options[no_of_custom_link]', array(
	'label'           	=> esc_html__( 'Number of Custom Links', 'edumag-pro' ),
	'description'		=> esc_html__( 'Enter number of custom links. Save and then refresh page to view changes. Min 1 and Max 3', 'edumag-pro' ),
	'section'         	=> 'edumag_pro_top_header_section',
	'active_callback' 	=> 'edumag_pro_is_custom_link_block_active',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'			=> 1,
		'max'			=> 3,
		'step'			=> 1
	)
) );

$no_of_custom_link =  edumag_pro_get_theme_options()['no_of_custom_link'];

for( $i=1; $i<= $no_of_custom_link; $i++ ){

	// Add contact link text setting and control.
	$wp_customize->add_setting( 'edumag_pro_theme_options[link_text_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( 'edumag_pro_theme_options[link_text_'. $i .']', array(
		'label'             => sprintf( esc_html__( 'Link Text #%s', 'edumag-pro' ), $i ),
		'section'           => 'edumag_pro_top_header_section',
		'active_callback' 	=> 'edumag_pro_is_custom_link_block_active',
	) );

	// Add  enable custom links block setting and control.
	$wp_customize->add_setting( 'edumag_pro_theme_options[custom_link_'. $i .']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'edumag_pro_theme_options[custom_link_'. $i .']', array(
		'label'             => sprintf( esc_html__( 'Custom Link #%s', 'edumag-pro' ), $i ),
		'section'           => 'edumag_pro_top_header_section',
		'type'              => 'url',
		'active_callback' 	=> 'edumag_pro_is_custom_link_block_active',
	) );

	// Add hr line
	$wp_customize->add_setting( 'edumag_pro_theme_options[custom_links_hr_line_'. $i .']', array(
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Edumag_Pro_Customize_Horizontal_Line( $wp_customize, 'edumag_pro_theme_options[custom_links_hr_line_'. $i .']', array(
		'section'         	=> 'edumag_pro_top_header_section',
		'type'            	=> 'hr',
		'active_callback' 	=> 'edumag_pro_is_top_header_active',
	) ) );
}