<?php
/**
 * EduMag Pro Trending Section Customizer options
 *
 * @package Theme Palace
 * @subpackage EduMag Pro
 * @since EduMag Pro 1.0
 */

// Add trending section enable section
$wp_customize->add_section( 'edumag_pro_trending_section', array(
  'title'             => esc_html__( 'Trending Section','edumag-pro'),
  'description'       => sprintf( '<b>%s</b><br><b>%s</b>%s', esc_html__( 'Trending Section Options', 'edumag-pro' ), esc_html__( 'Info: ', 'edumag-pro' ), esc_html__( 'New Custom Category ( Taxonomy ) will be added automatically to Content Type as its registered. To see list of custom categories ( Terms ), select custom category in content type and save. Then refresh the page to see the list of custom categories.', 'edumag-pro' ) ),
  'panel'             => 'edumag_pro_sections_panel'
) );

// Add trending section enable setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[trending_section_enable]', array(
  'default'           => $options['trending_section_enable'],
  'sanitize_callback' => 'edumag_pro_sanitize_select'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[trending_section_enable]', array(
  'label'             => esc_html__( 'Enable on', 'edumag-pro' ),
  'section'           => 'edumag_pro_trending_section',
  'type'              => 'select',
  'choices'           => edumag_pro_enable_disable_options()
) );

// Add trending section title setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[trending_section_title]', array(
  'default'           => $options['trending_section_title'],
  'transport'         => 'postMessage',
  'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[trending_section_title]', array(
  'label'             => esc_html__( 'Title', 'edumag-pro' ),
  'section'           => 'edumag_pro_trending_section',
  'active_callback'   => 'edumag_pro_is_trending_section_active',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
  $wp_customize->selective_refresh->add_partial( 'edumag_pro_theme_options[trending_section_title]', array(
    'selector'            => '#trending-courses h2.entry-title',
    'render_callback'     => 'edumag_pro_customize_partial_trending_section_title',
    'container_inclusive' => false,
    'fallback_refresh'    => true,
  ) );
}

// Add trending section sub title setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[trending_section_subtitle]', array(
  'default'           => $options['trending_section_subtitle'],
  'transport'         => 'postMessage',
  'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[trending_section_subtitle]', array(
  'label'             => esc_html__( 'Description', 'edumag-pro' ),
  'section'           => 'edumag_pro_trending_section',
  'type'              => 'textarea',
  'active_callback'   => 'edumag_pro_is_trending_section_active',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
  $wp_customize->selective_refresh->add_partial( 'edumag_pro_theme_options[trending_section_subtitle]', array(
    'selector'            => '#trending-courses p.sub-title',
    'render_callback'     => 'edumag_pro_customize_partial_trending_section_subtitle',
    'container_inclusive' => false,
    'fallback_refresh'    => true,
  ) );
}

// Add trending section content type setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[trending_section_content_type]', array(
  'default'           => $options['trending_section_content_type'],
  'sanitize_callback' => 'edumag_pro_sanitize_select'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[trending_section_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'edumag-pro' ),
    'section'           => 'edumag_pro_trending_section',
    'active_callback'   => 'edumag_pro_is_trending_section_active',
    'type'              => 'select',
    'choices'           =>  edumag_pro_information_taxonomy_content_type(),
) );

// Category Content Type
$wp_customize->add_setting(  'edumag_pro_theme_options[trending_section_content_category]', array(
  'sanitize_callback' => 'edumag_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Edumag_Pro_Multi_Select_Category_Control ( $wp_customize,'edumag_pro_theme_options[trending_section_content_category]', array(
  'label'             => esc_html__( 'Select Category', 'edumag-pro' ),
  'section'           => 'edumag_pro_trending_section',
  'type'              => 'dropdown-category',
  'active_callback'   => 'edumag_pro_is_trending_section_category_active'
) ) );

// Taxonomy Content Type
$wp_customize->add_setting(  'edumag_pro_theme_options[trending_courses_'. $options['trending_section_content_type'] .']', array(
  'sanitize_callback' => 'edumag_pro_sanitize_multi_select_taxonomies_control',
) ) ;

$wp_customize->add_control( new Edumag_Pro_Multi_Select_Taxonomies_Control ( $wp_customize,'edumag_pro_theme_options[trending_courses_'. $options['trending_section_content_type'] .']', array(
  'label'             => esc_html__( 'Select Terms', 'edumag-pro' ),
  'section'           => 'edumag_pro_trending_section',
  'taxonomy'          => $options['trending_section_content_type'],
  'type'              => 'dropdown-taxonomies',
  'active_callback' => 'edumag_pro_is_trending_section_taxonomy_active'
) ) );

// Add Trending section count.
$wp_customize->add_setting( 'edumag_pro_theme_options[trending_section_count]', array(
  'default'           => $options['trending_section_count'],
  'sanitize_callback' => 'edumag_pro_sanitize_number_range',
) );

$wp_customize->add_control( 'edumag_pro_theme_options[trending_section_count]', array(
  'label'             => esc_html__( 'No of Posts', 'edumag-pro' ),
  'section'           => 'edumag_pro_trending_section',
  'type'              => 'number',
  'active_callback'   => 'edumag_pro_is_trending_section_not_demo',
  'input_attrs'   => array(
    'max' => 6,
    'min' => 1,
    'style' => 'width:100px'
    )
) );

/**
 * Subscription section
 */

if ( ! (class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'subscriptions' ) ) ) {
    $subscription_description = esc_html__( 'Subscription requires', 'edumag-pro' ) . sprintf( '<a target="_blank" href="%s"> %s </a>', esc_url( 'https://wordpress.org/plugins/jetpack/' ), esc_html__( 'JetPack Plugin', 'edumag-pro' ) ) . esc_html__( 'with Subscription module Enabled.', 'edumag-pro' );
  } else{
    $subscription_description = '';
}

// Enable subscription setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[trending_section_enable_subscription]', array(
  'sanitize_callback' => 'edumag_pro_sanitize_checkbox',
  'default'           => $options['trending_section_enable_subscription']
) );

$wp_customize->add_control( 'edumag_pro_theme_options[trending_section_enable_subscription]', array(
  'label'             => esc_html__( 'Enable Jetpack Subscription', 'edumag-pro' ),
  'description'       => $subscription_description,
  'section'           => 'edumag_pro_trending_section',
  'type'              => 'checkbox',
  'active_callback'   => 'edumag_pro_is_trending_section_not_demo',
) );

// Add trending section subscription title setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[trending_section_subscription_title]', array(
  'default'           => $options['trending_section_subscription_title'],
  'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[trending_section_subscription_title]', array(
  'label'             => esc_html__( 'Subscription Title', 'edumag-pro' ),
  'section'           => 'edumag_pro_trending_section',
  'active_callback'   => 'edumag_pro_is_trending_section_subscription_active',
) );

// Add trending section subscription sub title setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[trending_section_subscription_subtitle]', array(
  'default'           => $options['trending_section_subscription_subtitle'],
  'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[trending_section_subscription_subtitle]', array(
  'label'             => esc_html__( 'Subscription Description', 'edumag-pro' ),
  'section'           => 'edumag_pro_trending_section',
  'type'              => 'textarea',
  'active_callback'   => 'edumag_pro_is_trending_section_subscription_active',
) );

// Add trending section subscription button text setting and control.
$wp_customize->add_setting( 'edumag_pro_theme_options[trending_section_subscription_button]', array(
  'default'           => $options['trending_section_subscription_button'],
  'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( 'edumag_pro_theme_options[trending_section_subscription_button]', array(
  'label'             => esc_html__( 'Subscription Button Text', 'edumag-pro' ),
  'section'           => 'edumag_pro_trending_section',
  'active_callback'   => 'edumag_pro_is_trending_section_subscription_active',
) );
