<?php
/**
 * Jetpack Compatibility File.
 *
 * @link https://jetpack.com/
 *
 * @package Theme Palace
 * @subpackage EduMag Pro
 * @since EduMag Pro 1.0
 */

if( !function_exists( 'edumag_pro_jetpack_setup' ) ) :
	/**
	 * Jetpack setup function.
	 *
	 * See: https://jetpack.com/support/infinite-scroll/
	 * See: https://jetpack.com/support/responsive-videos/
	 */
	function edumag_pro_jetpack_setup() {
		$options = edumag_pro_get_theme_options(); // get theme options

		$pagination_type = isset( $options['pagination_type'] ) ? $options['pagination_type'] : '';

		if ( in_array( $pagination_type, array( 'infinite-click', 'infinite-scroll' ) ) ) {
			if ( 'infinite-click' == $pagination_type ) {
				$type = 'click';
			} elseif( 'infinite-scroll' == $pagination_type ){
				$type = 'scroll';
			}
			// Add theme support for Infinite Scroll.
			add_theme_support( 'infinite-scroll', array(
				'type'      => $type,
				'container' => 'main',
				'render'    => 'edumag_pro_infinite_scroll_render',
				'wrapper'   => false,
				'footer'    => false,
			) );
		}

		// Add theme support for Responsive Videos.
		add_theme_support( 'jetpack-responsive-videos' );
	}
endif; 
add_action( 'after_setup_theme', 'edumag_pro_jetpack_setup' );

if( !function_exists( 'edumag_pro_infinite_scroll_render' ) ) :
	/**
	 * Custom render function for Infinite Scroll.
	 */
	function edumag_pro_infinite_scroll_render() {

		while ( have_posts() ) {
			the_post();

			if ( is_search() ) {
				get_template_part( 'template-parts/content', 'search' );
			}
			else {
				get_template_part( 'template-parts/content', get_post_format() );
			}
		}
	}
endif;